# pyslink

Soft link a file/directory with python site-packages directory.
Useful during development.

Installation via pip::

    pip install pyslink

Soft link a package::

    pyslink path/to/main/module
